@@ -4,7 +4,7 @@ from typing import Callable, List
 def tfrq(func: Callable, params: List, num_cores=None, config=None):
     import math
     from concurrent.futures import ProcessPoolExecutor
-    from helpers import param_list, config_default_values
+    from tfrq_helpers import param_list, config_default_values
     import os
 
     if num_cores is None:
